@@ -5,7 +5,6 @@
  * Version numbers for the different parts of Weaver included here.
  *
  */
-
 #ifndef __WVVER_H
 #define __WVVER_H
 
@@ -17,14 +16,14 @@
 //  valid string, eg "4.5 beta 6"
 //
 
-#define WEAVER_VER		0x000369f0
-#define WEAVER_VER_STRING	"3.70pre0 (dev)"
+#define WEAVER_VER		0x00037602
+#define WEAVER_VER_STRING	"3.76 #2"
 
-#define WVSTREAMS_VER		0x00037000
-#define WVSTREAMS_VER_STRING	"3.70"
+#define WVSTREAMS_VER		0x00037600
+#define WVSTREAMS_VER_STRING	"3.75.0"
 
-#define WVDIAL_VER		0x00015300
-#define WVDIAL_VER_STRING	"1.53"
+#define WVDIAL_VER		0x00015400
+#define WVDIAL_VER_STRING	"1.54"
 
 #define FASTFORWARD_VER		0x00010100
 #define FASTFORWARD_VER_STRING	"1.01"
@@ -32,8 +31,8 @@
 #define TUNNELV_VER		0x00023000
 #define TUNNELV_VER_STRING	"2.30"
 
-#define WVTAPE_VER              0x00010300
-#define WVTAPE_VER_STRING       "1.03"
+#define WVTAPE_VER              0x00011200
+#define WVTAPE_VER_STRING       "1.12"
 
 #define RETCHMAIL_VER		0x00000300
 #define RETCHMAIL_VER_STRING    "0.03"
@@ -44,4 +43,11 @@
 #define WVPRINT_VER		0x00000100
 #define WVPRINT_VER_STRING	"0.01"
 
+#define POLLY_VER               0x00000000
+#define POLLY_VER_STRING        "0.00 (Danger!)"
+
+#define WVSYSLOGD_VER           0x00000000
+#define WVSYSLOGD_VER_STRING    "0.00 (Deadly!)"
+
 #endif // __WVVER_H
+
